@@ -1,5 +1,5 @@
 # Verilog - Verilog Perl Interface
-# $Id: Module.pm,v 1.8 2002/05/03 13:55:00 wsnyder Exp $
+# $Revision: #11 $$Date: 2002/08/07 $$Author: wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -7,9 +7,7 @@
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of either the GNU General Public License or the
-# Perl Artistic License, with the exception that it cannot be placed
-# on a CD-ROM or similar media for commercial distribution without the
-# prior approval of the author.
+# Perl Artistic License.
 # 
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -32,7 +30,7 @@ use Verilog::Netlist::Pin;
 use Verilog::Netlist::Subclass;
 @ISA = qw(Verilog::Netlist::Module::Struct
 	Verilog::Netlist::Subclass);
-$VERSION = '2.200';
+$VERSION = '2.210';
 use strict;
 
 structs('new',
@@ -54,7 +52,7 @@ structs('new',
 	   _autocovers  => '%', #'	# Hash of covers found in code
 	   _autosignal	=> '$', #'	# Module has /*AUTOSIGNAL*/ in it
 	   _autosubcells=> '$', #'	# Module has /*AUTOSUBCELL_DECL*/ in it
-	   _autotrace	=> '$', #'	# Module has /*AUTOTRACE*/ in it
+	   _autotrace	=> '%', #'	# Module has /*AUTOTRACE*/ in it
 	   _autoinoutmod=> '$', #'	# Module has /*AUTOINOUT_MODULE*/ in it
 	   _ctor	=> '$', #'	# Module has SC_CTOR in it
 	   _code_symbols=> '$', #'	# Hash ref of symbols found in raw code
